@@ -11,9 +11,16 @@ _iot_client = client("iot", region_name=environ["AWS_REGION"])
 
 
 class IoTJobHandler(_BaseIoT):
-    def __init__(self, thing_name: str, account_id: str):
+    def __init__(self, thing_name: str, account_id: str = None):
         super(IoTJobHandler, self).__init__(thing_name)
-        self.__account_id = account_id
+        if account_id:
+            self.__account_id = account_id
+        elif "AWS_ACCOUNT_ID" in environ:
+            self.__account_id = environ["AWS_ACCOUNT_ID"]
+        else:
+            raise ValueError("missing account id:\n"
+                             "for using IoTJobHandler account id must either be given as argument or "
+                             "defined in os.environ as AWS_ACCOUNT_ID")
 
     def execute(self, job_document: dict, job_id: str = None):
         if self.__account_id is None:
